@@ -31,14 +31,12 @@ use Sbuild::LogBase;
 require Exporter;
 @Buildd::ISA = qw(Exporter);
 
-@Buildd::EXPORT = qw(unset_env lock_file unlock_file open_log
- 		     reopen_log close_log send_mail
+@Buildd::EXPORT = qw(unset_env lock_file unlock_file send_mail
  		     ll_send_mail exitstatus isin);
 
 $Buildd::lock_interval = 15;
 $Buildd::max_lock_trys = 120;
 ($Buildd::progname = $0) =~ s,.*/,,;
-$Buildd::progpid = $$;
 my @pwinfo = getpwuid($>);
 $Buildd::username = $pwinfo[0];
 $Buildd::gecos = $pwinfo[6];
@@ -50,9 +48,6 @@ sub isin ($@);
 sub unset_env ();
 sub lock_file ($;$);
 sub unlock_file ($);
-sub open_log ($);
-sub close_log ($);
-sub reopen_log ($);
 sub send_mail ($$$;$);
 sub ll_send_mail ($$);
 sub exitstatus ($);
@@ -96,6 +91,9 @@ sub lock_file ($;$) {
 	    goto repeat if !open( F, "<$lockfile" );
 	    my $line = <F>;
 	    close( F );
+	    # If this goes wrong it would be a spinlock and the world will
+	    # end.
+	    goto repeat if !defined( $line );
 	    if ($line !~ /^(\d+)\s+([\w\d.-]+)$/) {
 		warn "Bad lock file contents ($lockfile) -- still trying\n";
 	    }
@@ -136,49 +134,6 @@ sub unlock_file ($) {
     unlink( $lockfile );
 }
 
-sub open_log ($) {
-    my $conf = shift;
-
-    my $logfile = $conf->get('DAEMON_LOG_FILE');
-
-    my $log = new FileHandle(">>$logfile")
-	or die "$0: Cannot open logfile $logfile: $!\n";
-    chmod( 0640, "$logfile" )
-	or die "$0: Cannot set modes of $logfile: $!\n";
-
-    my $logfunc = sub {
-	my $F = shift;
-	my $message = shift;
-
-	my $t;
-	my $text = "";
-
-	# omit weekday and year for brevity
-	($t = localtime) =~ /^\w+\s(.*)\s\d+$/; $t = $1;
-	$message =~ s/\n+$//; # remove newlines at end
-	$message = "$t $Buildd::progname\[$Buildd::progpid\]: $message\n";
-
-	print $F $message;
-    };
-
-    return Sbuild::LogBase::open_log($conf, $log, $logfunc);
-}
-
-sub close_log ($) {
-    my $conf = shift;
-
-    Sbuild::LogBase::close_log($conf);
-}
-
-sub reopen_log ($) {
-    my $conf = shift;
-
-    my $errno = $!;
-
-    close_log($conf);
-    open_log($conf);
-    $! = $errno;
-}
 
 sub send_mail ($$$;$) {
     my $addr = shift;
