@@ -24,7 +24,6 @@ package Sbuild::ConfBase;
 use strict;
 use warnings;
 
-use Cwd qw(cwd);
 use Sbuild qw(isin);
 
 BEGIN {
@@ -199,12 +198,6 @@ sub init_allowed_keys {
 	    DEFAULT => $username,
 	    HELP => 'Username used for building.  Should not require setting.'
 	},
-	'CWD'					=> {
-	    TYPE => 'STRING',
-	    GROUP => '__INTERNAL',
-	    DEFAULT => cwd(),
-	    HELP => 'Current working directory at time of configuration reading.'
-	},
 	'VERBOSE'				=> {
 	    TYPE => 'NUMERIC',
 	    VARNAME => 'verbose',
